unit swarecheck;

{*******************************************************************************
*  TSharewareCheck version 1.0                                                 *
********************************************************************************
* Author: Raoul Snyman                                                         *
* ---------------------------------------------------------------------------- *
* E-Mail: components@saturnlaboratories.gq.nu                                  *
* ---------------------------------------------------------------------------- *
* Copyright: 2001 Saturn Laboratories, All rights reserved.                   *
* ---------------------------------------------------------------------------- *
* Description: TSharewareCheck is a component which sets and checks to see if  *
*              a program has reached its expiry date. Set the number of days   *
*              and call SetExpiry to set the expiry date to the number of days *
*              from when you called SetExpiry. Call Expired to see if the      *
*              program has expired yet. Call DaysLeft to find out how many     *
*              days are left over before the program expires.                  *
********************************************************************************
* This component is FREEWARE.                                                  *
* ---------------------------------------------------------------------------- *
* Please let me know if you find it useful!!                                   *
* ---------------------------------------------------------------------------- *
* It may be used for commercial purposes on the condition that you give me     *
* credit (i.e. place it in your credits list). Check out my TScrollingCredits. *
* ---------------------------------------------------------------------------- *
* If used in freeware, it's not necessary to give me credit, although it would *
* be appreciated.                                                              *
* ---------------------------------------------------------------------------- *
* If you modify this code, please send me an e-mail with a copy of the code    *
* attached, letting me know what it was that you changed/modified/added.       *
*******************************************************************************}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, Registry;

type
  TRootKey = (rkAllUsers, rkCurrentUser, rkLocalMachine,
              rkClassesRoot, rkCurrentConfig, rkDynData);

  TSharewareCheck = class(TComponent)
  private
    { Private declarations }
    FNumberOfDays: Integer;
    FDaysLeft: Integer;
    FRootKey: TRootKey;
    FRegistryKey: HKEY;
    FRegKey: String;
    procedure SetRootKey(Value: TRootKey);
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure SetExpiry;
    function Expired: Boolean;
    function DaysLeft: Integer;
  published
    { Published declarations }
    property NumberOfDays: Integer read FNumberOfDays write FNumberOfDays;
    property Root: TRootKey read FRootKey write SetRootKey;
    property RegistryKey: String read FRegKey write FRegKey;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Samples', [TSharewareCheck]);
end;

constructor TSharewareCheck.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  NumberOfDays:= 30;
  FDaysLeft := 30;
  Root := rkLocalMachine;
  RegistryKey := 'Software\MyProgram';
end;

procedure TSharewareCheck.SetExpiry;
var Reg: TRegistry;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := FRegistryKey;
 Reg.OpenKey(FRegKey, True);
 Reg.WriteDateTime('InstallDate', Date);
 Reg.CloseKey;
 Reg.Free;
end;

function TSharewareCheck.Expired: Boolean;
var Reg: TRegistry;
    Dt1, Dt2: TDateTime;
    Exp: Boolean;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := FRegistryKey;
 if Reg.KeyExists(FRegKey) and Reg.OpenKey(FRegKey, False) and Reg.ValueExists('InstallDate')
  then
   begin
    Dt1 := Reg.ReadDateTime('InstallDate');
    Reg.CloseKey;
    Dt2 := Date;
    if Dt2 >= (Dt1 + FNumberOfDays)
     then Exp := True
     else Exp := False;
    FDaysLeft := FNumberOfDays - Round(Dt2 - Dt1);
    if FDaysLeft < 0
     then FDaysLeft := 0;
   end
  else Exp := True;
 Reg.Free;
 Expired := Exp;
end;

function TSharewareCheck.DaysLeft: Integer;
begin
 if Expired
  then DaysLeft := 0
  else DaysLeft := FDaysLeft;
end;

procedure TSharewareCheck.SetRootKey(Value: TRootKey);
begin
 FRootKey := Value;
 Case Value Of
  rkClassesRoot: FRegistryKey := HKEY_CLASSES_ROOT;
  rkCurrentUser: FRegistryKey := HKEY_CURRENT_USER;
  rkLocalMachine: FRegistryKey := HKEY_LOCAL_MACHINE;
  rkAllUsers: FRegistryKey := HKEY_USERS;
  rkCurrentConfig: FRegistryKey := HKEY_CURRENT_CONFIG;
  rkDynData: FRegistryKey := HKEY_DYN_DATA;
 End;
end;

end.
